package main

import (
	"context"
	"flag"
	"log"
	"os"
	"path/filepath"

	"git.netflux.io/rob/kubectl-persistent-logger/logs"
	"k8s.io/client-go/kubernetes"
	"k8s.io/client-go/tools/clientcmd"
	"k8s.io/client-go/util/homedir"
)

func main() {
	var (
		kubeconfig                 *string
		deployName                 *string
		container                  *string
		allowNonExistentDeployment *bool
	)
	if home := homedir.HomeDir(); home != "" {
		kubeconfig = flag.String("kubeconfig", filepath.Join(home, ".kube", "config"), "(optional) absolute path to the kubeconfig file")
	} else {
		kubeconfig = flag.String("kubeconfig", "", "absolute path to the kubeconfig file")
	}
	deployName = flag.String("deployment", "", "name of a deployment to monitor")
	container = flag.String("container", "", "name of a specific container")
	allowNonExistentDeployment = flag.Bool("allow-nonexistent", true, "allow deployment to be non-existent on launch")
	flag.Parse()

	config, err := clientcmd.BuildConfigFromFlags("", *kubeconfig)
	if err != nil {
		log.Fatal(err)
	}

	clientset, err := kubernetes.NewForConfig(config)
	if err != nil {
		log.Fatal(err)
	}

	ctx := context.Background()
	watcher := logs.NewWatcher(
		*deployName,
		*container,
		*allowNonExistentDeployment,
		logs.KubernetesClient{Interface: clientset},
		logs.NewPodWatcher,
		os.Stdout,
	)
	if err := watcher.Watch(ctx); err != nil {
		log.Fatal(err)
	}
}
